aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/rpc/consul.rs6
-rw-r--r--src/util/config.rs4
2 files changed, 5 insertions, 5 deletions
diff --git a/src/rpc/consul.rs b/src/rpc/consul.rs
index cf050207..b1772a1a 100644
--- a/src/rpc/consul.rs
+++ b/src/rpc/consul.rs
@@ -100,8 +100,8 @@ impl ConsulDiscovery {
pub async fn get_consul_nodes(&self) -> Result<Vec<(NodeID, SocketAddr)>, ConsulError> {
let url = format!(
- "http://{}/v1/catalog/service/{}",
- self.config.consul_host, self.config.service_name
+ "{}/v1/catalog/service/{}",
+ self.config.consul_http_addr, self.config.service_name
);
let http = self.client.get(&url).send().await?;
@@ -158,7 +158,7 @@ impl ConsulDiscovery {
},
};
- let url = format!("http://{}/v1/catalog/register", self.config.consul_host);
+ let url = format!("{}/v1/catalog/register", self.config.consul_http_addr);
let http = self.client.put(&url).json(&advertisement).send().await?;
http.error_for_status()?;
diff --git a/src/util/config.rs b/src/util/config.rs
index a85e025f..04f8375a 100644
--- a/src/util/config.rs
+++ b/src/util/config.rs
@@ -128,8 +128,8 @@ pub struct AdminConfig {
#[derive(Deserialize, Debug, Clone)]
pub struct ConsulDiscoveryConfig {
- /// Consul host to connect to to discover more peers
- pub consul_host: String,
+ /// Consul http or https address to connect to to discover more peers
+ pub consul_http_addr: String,
/// Consul service name to use
pub service_name: String,
/// CA TLS certificate to use when connecting to Consul